==> jaxx-demo-2.7-sources.jar: jaxx/demo/component/jaxx/editor/SimpleTimeEditorDemoHandler.java <==
package jaxx.demo.component.jaxx.editor;

/*
 * #%L
 * JAXX :: Demo
 * $Id: SimpleTimeEditorDemoHandler.java 2765 2014-01-08 18:55:30Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jaxx/tags/jaxx-2.7/jaxx-demo/src/main/java/jaxx/demo/component/jaxx/editor/SimpleTimeEditorDemoHandler.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import jaxx.runtime.spi.UIHandler;

/**
 * Created on 11/22/13.
 *
 * @author Tony CHEMIT <chemit@codelutin.com>
 * @since 2.6
 */
public class SimpleTimeEditorDemoHandler implements UIHandler<SimpleTimeEditorDemo> {
    @Override
    public void beforeInit(SimpleTimeEditorDemo ui) {

    }

    @Override
    public void afterInit(SimpleTimeEditorDemo ui) {
        // init time editor
        ui.editor.init();

        // set current time in model
        ui.demoModel.setTime(new java.util.Date());
    }
}

==> jaxx-demo-2.8-sources.jar: jaxx/demo/component/jaxx/editor/SimpleTimeEditorDemoHandler.java <==
package jaxx.demo.component.jaxx.editor;

/*
 * #%L
 * JAXX :: Demo
 * $Id: SimpleTimeEditorDemoHandler.java 2765 2014-01-08 18:55:30Z tchemit $
 * $HeadURL: https://nuiton.org/svn/jaxx/tags/jaxx-2.8/jaxx-demo/src/main/java/jaxx/demo/component/jaxx/editor/SimpleTimeEditorDemoHandler.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import jaxx.runtime.spi.UIHandler;

/**
 * Created on 11/22/13.
 *
 * @author Tony CHEMIT <chemit@codelutin.com>
 * @since 2.6
 */
public class SimpleTimeEditorDemoHandler implements UIHandler<SimpleTimeEditorDemo> {
    @Override
    public void beforeInit(SimpleTimeEditorDemo ui) {

    }

    @Override
    public void afterInit(SimpleTimeEditorDemo ui) {
        // init time editor
        ui.editor.init();

        // set current time in model
        ui.demoModel.setTime(new java.util.Date());
    }
}
